<?php
/**
* Social profiles options
*
* @package GridFeel WordPress Theme
* @copyright Copyright (C) 2023 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function gridfeel_social_profiles($wp_customize) {

    $wp_customize->add_section( 'gridfeel_section_social', array( 'title' => esc_html__( 'Social Links Options', 'gridfeel' ), 'panel' => 'gridfeel_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'gridfeel_options[social_buttons_location]', array( 'default' => 'secondary-menu', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridfeel_sanitize_social_buttons_location' ) );

    $wp_customize->add_control( 'gridfeel_social_buttons_location_control', array( 'label' => esc_html__( 'Social + Search + Login/Logout Buttons Location', 'gridfeel' ), 'description' => esc_html__('Select where you want to display social buttons.', 'gridfeel'), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[social_buttons_location]', 'type' => 'select', 'choices' => array( 'primary-menu' => esc_html__( 'Primary Menu', 'gridfeel' ), 'secondary-menu' => esc_html__( 'Secondary Menu', 'gridfeel' ) ) ) );

    $wp_customize->add_setting( 'gridfeel_options[hide_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridfeel_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridfeel_hide_social_buttons_control', array( 'label' => esc_html__( 'Hide Social + Search + Login/Logout Buttons', 'gridfeel' ), 'description' => esc_html__('If you checked this option, there is no any effect from these option: "Hide Search Button", "Show Login/Logout Button".', 'gridfeel'), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[hide_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridfeel_options[hide_search_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridfeel_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridfeel_hide_search_button_control', array( 'label' => esc_html__( 'Hide Search Button', 'gridfeel' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridfeel'), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[hide_search_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridfeel_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridfeel_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridfeel_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button', 'gridfeel' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridfeel'), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridfeel_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_twitterlink_control', array( 'label' => esc_html__( 'Twitter URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[googlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) ); 

    $wp_customize->add_control( 'gridfeel_googlelink_control', array( 'label' => esc_html__( 'Google Plus URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[googlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'gridfeel_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_vklink_control', array( 'label' => esc_html__( 'VK Link', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_githublink_control', array( 'label' => esc_html__( 'Github URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridfeel_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridfeel_sanitize_email' ) );

    $wp_customize->add_control( 'gridfeel_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridfeel_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridfeel_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'gridfeel' ), 'section' => 'gridfeel_section_social', 'settings' => 'gridfeel_options[rsslink]', 'type' => 'text' ) );

}